@@ -23,5 +23,10 @@ from ._hyperelasticity_anisotropic import (
     holzapfel_gasser_ogden,
 )
 
+from ._pseudo_elasticity import ogden_roxburgh
+from ._misc import morph
+
 from . import microsphere
 from .microsphere.nonaffine import miehe_goektepe_lulei
+
+from ._templates import NeoHookeOgdenRoxburgh, Morph
